Class: Cornucopia::Capybara::FinderDiagnostics::FindAction::FoundElement

Inherits:
Object
  • Object
show all
Defined in:
lib/cornucopia/capybara/finder_diagnostics.rb

Constant Summary collapse

ELEMENT_ATTRIBUTES =
[
    "text",
    "value",
    "visible?",
    "checked?",
    "selected?",
    "tag_name",
    "location",
    "id",
    "src",
    "name",
    "href",
    "style",
    "path",
    "outerHTML"
]
NATIVE_ATTRIBUTES =
[
    "size",
    "type"
]
PREDEFINED_ATTRIBUTES =
NATIVE_ATTRIBUTES + ELEMENT_ATTRIBUTES

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(found_element) ⇒ FoundElement

Returns a new instance of FoundElement.



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/cornucopia/capybara/finder_diagnostics.rb', line 461

def initialize(found_element)
  @found_element = found_element
  ELEMENT_ATTRIBUTES.each do |attrib|
    variable_name = attrib.to_s.gsub("?", "")
    instance_variable_set("@elem_#{variable_name}", get_attribute(attrib))
  end

  NATIVE_ATTRIBUTES.each do |attrib|
    instance_variable_set("@native_#{attrib}", get_native_attribute(attrib))
  end

  instance_variable_set("@native_class", @found_element[:class])

  if ::Capybara.current_session.driver.respond_to?(:browser) &&
      ::Capybara.current_session.driver.browser.method(:execute_script).arity != 1
    begin
      # This is a "trick" that works with Selenium, but which might not work with other drivers...
      script = "var attrib_list = [];
var attrs = arguments[0].attributes;
for (var nIndex = 0; nIndex < attrs.length; nIndex += 1)
{
  var a = attrs[nIndex];
  attrib_list.push(a.name);
};
return attrib_list;"

      attributes = ::Capybara.current_session.driver.browser.execute_script(script, @found_element.native)
      attributes.each do |attritue|
        unless PREDEFINED_ATTRIBUTES.include?(attritue)
          instance_variable_set("@native_#{attritue}", @found_element[attritue])
        end
      end

      @elem_outerHTML ||= ::Capybara.current_session.driver.browser.execute_script("return arguments[0].outerHTML", @found_element.native)
    rescue ::Capybara::NotSupportedByDriverError
    end
  end

  # information from Selenium that may not be available depending on the form, the full outerHTML of the element
  if (::Capybara.current_session.respond_to?(:evaluate_script))
    unless (@elem_id.blank?)
      begin
        @elem_outerHTML ||= ::Capybara.current_session.evaluate_script("document.getElementById('#{@elem_id}').outerHTML")
      rescue ::Capybara::NotSupportedByDriverError
      end
    end
  end
end

Instance Attribute Details

#found_element ⇒ Object (readonly)

Returns the value of attribute found_element.



431
432
433
# File 'lib/cornucopia/capybara/finder_diagnostics.rb', line 431

def found_element
  @found_element
end

Instance Method Details

#==(comparison_object) ⇒ Object



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/cornucopia/capybara/finder_diagnostics.rb', line 433

def ==(comparison_object)
  comparison_object.equal?(self) ||
      (comparison_object.instance_of?(self.class) &&
          (comparison_object.found_element == found_element
          # ||
          #     (comparison_object.instance_variable_get(:@elem_text) == @elem_text &&
          #         comparison_object.instance_variable_get(:@elem_value) == @elem_value &&
          #         comparison_object.instance_variable_get(:@elem_visible) == @elem_visible &&
          #         comparison_object.instance_variable_get(:@elem_checked) == @elem_checked &&
          #         comparison_object.instance_variable_get(:@elem_selected) == @elem_selected &&
          #         comparison_object.instance_variable_get(:@elem_tag_name) == @elem_tag_name &&
          #         comparison_object.instance_variable_get(:@elem_location) == @elem_location &&
          #         comparison_object.instance_variable_get(:@elem_size) == @elem_size &&
          #         comparison_object.instance_variable_get(:@elem_id) == @elem_id &&
          #         comparison_object.instance_variable_get(:@elem_name) == @elem_name &&
          #         comparison_object.instance_variable_get(:@elem_href) == @elem_href &&
          #         comparison_object.instance_variable_get(:@elem_style) == @elem_style &&
          #         comparison_object.instance_variable_get(:@elem_path) == @elem_path &&
          #         comparison_object.instance_variable_get(:@elem_outerHTML) == @elem_outerHTML &&
          #         comparison_object.instance_variable_get(:@native_class) == @native_class &&
          #         comparison_object.instance_variable_get(:@native_value) == @native_value &&
          #         comparison_object.instance_variable_get(:@native_type) == @native_type
          #     )
          )
      ) ||
      comparison_object == found_element
end

#get_attribute(attribute) ⇒ Object



510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/cornucopia/capybara/finder_diagnostics.rb', line 510

def get_attribute(attribute)
  if @found_element.respond_to?(attribute)
    begin
      @found_element.send(attribute)
    rescue ::Capybara::NotSupportedByDriverError
    end
  elsif @found_element.respond_to?(:[]) && @found_element[attribute]
    @found_element[attribute]
  else
    get_native_attribute(attribute)
  end
end

#get_native_attribute(attribute) ⇒ Object



523
524
525
526
527
528
529
530
531
# File 'lib/cornucopia/capybara/finder_diagnostics.rb', line 523

def get_native_attribute(attribute)
  if @found_element.native.respond_to?(attribute)
    @found_element.native.send(attribute)
  elsif @found_element.native.respond_to?(:[])
    @found_element.native[attribute]
  else
    nil
  end
end