Class: Cornucopia::Util::Configuration
- Inherits:
-
Object
- Object
- Cornucopia::Util::Configuration
- Includes:
- Singleton
- Defined in:
- lib/cornucopia/util/configuration.rb
Instance Attribute Summary collapse
-
#configurations ⇒ Object
Returns the value of attribute configurations.
Class Method Summary collapse
-
.add_log_file(log_file_name, options = {}) ⇒ Object
Adds the specified log file to the list of log files to capture.
-
.analyze_find_exceptions ⇒ Object
This setting is used by the Capybara utilities.
- .analyze_find_exceptions=(value) ⇒ Object
-
.analyze_selector_exceptions ⇒ Object
This setting is used by the Capybara utilities.
- .analyze_selector_exceptions=(value) ⇒ Object
-
.auto_open_report_after_generation(open_report, report_name = nil) ⇒ Object
To make it easier to know about and to see the reports, this configuration will cause a report to be automatically opened if there is anything to report when the report is closed.
- .backup_logs_on_failure ⇒ Object
-
.backup_logs_on_failure=(value) ⇒ Object
backup_logs_on_failure causes the system to copy the log files at the end of the report cycle if there were any errors during the creation of the report system.
-
.base_folder ⇒ Object
Sets or returns the name of the folder to generate reports into.
- .base_folder=(value) ⇒ Object
-
.benchmark ⇒ Object
Turns benchmarking on or off.
- .benchmark=(value) ⇒ Object
- .context_seed ⇒ Object
-
.context_seed=(value) ⇒ Object
rand_context_seed is the seed value used to seed the srand function at the start of a context.
-
.default_num_lines=(value) ⇒ Object
default_num_lines sets the default number of lines to extract from the log file.
-
.default_report_configuration(report_name) ⇒ Object
returns the report configuration object for that type of report.
- .grab_logs ⇒ Object
-
.grab_logs=(value) ⇒ Object
grab_logs indicates if the system should try to automatically grab a tail of the log file if outputing a diagnostics report.
-
.ignore_finder_errors_on_success ⇒ Object
This setting is used by the report builder.
- .ignore_finder_errors_on_success=(value) ⇒ Object
-
.ignore_has_selector_errors ⇒ Object
This setting is used by the matcher analysis.
- .ignore_has_selector_errors=(value) ⇒ Object
-
.num_lines(log_file_name = nil) ⇒ Object
num_lines returns the number of lines that will be grabbed for a file.
- .open_report_after_generation(report_name) ⇒ Object
- .order_seed ⇒ Object
-
.order_seed=(value) ⇒ Object
order_seed is the seed value used to set the order that randomly ordered tests are run in.
-
.print_timeout_min ⇒ Object
Sets or returns the minimum amount of time in seconds to allow for the printing of variables.
- .print_timeout_min=(value) ⇒ Object
-
.record_test_start_and_end_format ⇒ Object
This setting is used by the test system hooks.
- .record_test_start_and_end_format=(value) ⇒ Object
-
.record_test_start_and_end_in_log ⇒ Object
This setting is used by the test system hooks.
- .record_test_start_and_end_in_log=(value) ⇒ Object
-
.remove_log_file(log_file_name) ⇒ Object
Removes the specified log file from the list of log files to capture.
-
.report_configuration(report_name) ⇒ Object
returns the report configuration object for that type of report.
-
.retry_match_with_found ⇒ Object
Sometimes, the analysis process found the element when it wasn't found other ways.
- .retry_match_with_found=(value) ⇒ Object
-
.retry_with_found ⇒ Object
Sometimes, the analysis process found the element when it wasn't found other ways.
- .retry_with_found=(value) ⇒ Object
- .seed ⇒ Object
-
.seed=(value) ⇒ Object
rand_seed is the seed value used to seed the srand function at the start of a test suite.
-
.selenium_cache_retry_count ⇒ Object
The Selenium driver can throw a StaleElementReferenceError exception sometimes.
- .selenium_cache_retry_count=(value) ⇒ Object
-
.set_report_configuration(report_name, configuration) ⇒ Object
sets the report configuration object for that type of report from a configuration has that is passed in.
- .suite_seed ⇒ Object
-
.suite_seed=(value) ⇒ Object
rand_suite_seed is the seed value used to seed the srand function at the start of a context.
-
.user_log_files ⇒ Object
user_log_files returns a hash of all of the log files which the user has specified are to be grabbed.
Instance Method Summary collapse
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/cornucopia/util/configuration.rb', line 15 def initialize @configurations = Cornucopia::Util::GenericSettings.new configurations.order_seed = nil configurations.rand_seed = nil configurations.rand_context_seed = nil configurations.rand_suite_seed = nil configurations.user_log_files = {} configurations.default_num_lines = 500 configurations.grab_logs = true configurations.backup_logs_on_failure = false configurations.print_timeout_min = 10 configurations.selenium_cache_retry_count = 5 configurations.analyze_find_exceptions = true configurations.analyze_selector_exceptions = true configurations.ignore_finder_errors_on_success = true configurations.ignore_has_selector_errors = true configurations.record_test_start_and_end_in_log = true configurations.record_test_start_and_end_format = "******** %{start_end}: %{test_name}" configurations.retry_with_found = false configurations.retry_match_with_found = false configurations.open_report_settings = { default: false } configurations.base_folder = "cornucopia_report" configurations.benchmark = false # configurations.alternate_retry = false configurations.default_configuration = { rspec: { min_fields: [ :example__full_description, :example__location, :example__exception__to_s, :example__exception__backtrace ], more_info_fields: [ :example__exception__class__name, :example, :seeds__seed_value, :seeds__context_seed_value, :seeds__suite_seed_value, :example__example_group_instance, :example__metadata__caller, { report_element: :rspec__configuration__seed, report_options: { ignore_missing: true } }, { report_element: :rspec__configuration__ordering_manager__seed, report_options: { ignore_missing: true } }, :logs, :capybara_page_diagnostics ], expand_fields: [ :example, :example__example_group_instance____memoized, :example__example_group_instance____memoized__memoized, :example__example_group_instance__response, :example__example_group_instance__controller, :example__example_group_instance__request, :example__example_group_instance__request__env, :example__example_group_instance ], expand_inline_fields: [ :example__example_group_instance____memoized, :example__example_group_instance____memoized__memoized ], exclude_fields: [ :example__fixture_connections, :example, :example__reporter, :example__example_group_instance, :example__example_group_instance____memoized__mutex, :example__example_group_instance__controller___request, :example__example_group_instance__controller___response, :example__example_group_instance__controller___routes, :example__example_group_instance__request__filtered_env, :example__example_group_instance__routes, :example__example_group_instance___routes, "example__example_group_instance__request__env__action_dispatch.routes", "example__example_group_instance__request__env__action_controller.instance", ], }, cucumber: { min_fields: [ { report_element: :scenario__feature__title, report_options: { label: "feature", ignore_missing: true } }, { report_element: :scenario__feature__name, report_options: { label: "feature", ignore_missing: true } }, { report_element: :scenario__feature__location, # report_options: { format: ->(value) { "#{value.file}:#{value.line}" } } report_options: { format_object: Cornucopia::Util::CucumberFormatter, format_function: :format_location } }, { report_element: :scenario__title, report_options: { label: "scenario" } }, { report_element: :scenario__location, report_options: { format_object: Cornucopia::Util::CucumberFormatter, format_function: :format_location } }, :scenario__exception__to_s, :scenario__exception__backtrace ], more_info_fields: [ :scenario__exception__class__name, :scenario, :scenario__seed_value, # :scenario__feature__comment, :scenario__feature__keyword, :scenario__feature__description, { report_element: :scenario__feature__gherkin_statement, report_options: { ignore_missing: true } }, :scenario__feature__tags, # :scenario__current_visitor__configuration, :cucumber, :logs, :capybara_page_diagnostics ], expand_fields: [ :scenario, :cucumber, ], expand_inline_fields: [ ], exclude_fields: [ :scenario__background, :scenario__feature, :scenario__current_visitor, :scenario__raw_steps, :scenario__title, :scenario__location, :cucumber____cucumber_runtime, :cucumber____natural_language, :cucumber___rack_test_sessions, :cucumber___rack_mock_sessions, :cucumber__integration_session ] }, cucumber_outline: { min_fields: [ { report_element: :scenario__scenario_outline__name, report_options: { label: "feature_outline" } }, { report_element: :scenario__name, report_options: { label: "scenario_example" } }, { report_element: :scenario__scenario_outline__example_sections__0__0__0, # report_options: { format: ->(value) { "#{value.file}:#{value.line}" } } report_options: { format_object: Cornucopia::Util::CucumberFormatter, format_function: :format_location } }, :scenario__exception__to_s, :scenario__exception__backtrace ], more_info_fields: [ :scenario__exception__class__name, :scenario, :scenario__scenario_outline__example_sections__0__1__comments, :scenario__scenario_outline__example_sections__0__1__keyword, :scenario__scenario_outline__example_sections__0__1__description, :scenario__source_tag_names, :scenario__scenario_outline__example_sections__0__1__tags, :scenario__scenario_outline__example_sections__0__0, :scenario__scenario_outline, :cucumber, :logs, :capybara_page_diagnostics ], expand_fields: [ :scenario, :scenario__scenario_outline, :cucumber, ], expand_inline_fields: [ ], exclude_fields: [ :scenario__background, :scenario__scenario_outline__background, :scenario__table, :scenario__feature, :scenario__current_visitor, :scenario__raw_steps, :scenario__title, :cucumber____cucumber_runtime, :cucumber____natural_language, :cucumber___rack_test_sessions, :cucumber___rack_mock_sessions, :cucumber__integration_session ] }, spinach: { min_fields: [ :failure_description, :running_scenario__feature__name, :running_scenario__name, :running_scenario__line, :step_data__name, :step_data__line, :exception__to_s, :exception__backtrace ], more_info_fields: [ :exception__class__name, :running_scenario__feature__tags, :running_scenario, :step_data, :step_definitions, :logs, :capybara_page_diagnostics ], expand_fields: [ :running_scenario, :step_data, :step_definitions ], expand_inline_fields: [ ], exclude_fields: [ :running_scenario__feature, :step_data__scenario__feature, :running_scenario__name, :running_scenario__line, :step_data__name, :step_data__line ] }, capybara_page_diagnostics: { min_fields: [ :capybara__page_url, :capybara__title, :capybara__screen_shot ], more_info_fields: [ :capybara, :capybara__other_windows, ], expand_fields: [ :capybara, :capybara__other_windows, "capybara__other_windows__*", ], expand_inline_fields: [ :capybara, ], exclude_fields: [ :capybara__page_url, :capybara__screen_shot, :capybara__title, :capybara__options, :capybara__report, :capybara__table, :capybara__unsupported_list, :capybara__allow_other_windows, :capybara__iterating, :capybara__session, :capybara__driver, :capybara__window_handles, :capybara__current_window, "capybara__other_windows__*__options", "capybara__other_windows__*__report", "capybara__other_windows__*__table", "capybara__other_windows__*__unsupported_list", "capybara__other_windows__*__allow_other_windows", "capybara__other_windows__*__iterating", "capybara__other_windows__*__session", "capybara__other_windows__*__driver", "capybara__other_windows__*__window_handles", "capybara__other_windows__*__current_window" ], leaf_options: [ { report_element: [:html_source, :html_frame, :screen_shot ], report_options: { prevent_shrink: true, exclude_code_block: true, do_not_pretty_print: true } }, { report_element: [:html_file], report_options: { exclude_code_block: true }, } ] }, capybara_finder_diagnostics: { min_fields: [ :finder__function_name, :finder__args__0, :finder__search_args, :finder__options, :exception__to_s, :exception__backtrace ], more_info_fields: [ :exception__class__name, :finder, :capybara_page_diagnostics ], expand_fields: [ :finder, :finder__args, :finder__all_elements, :finder__all_other_elements, "finder__all_elements__*", "finder__all_other_elements__*", "finder__all_elements__*__native_size", "finder__all_other_elements__*__native_size", "finder__all_elements__*__elem_location", "finder__all_other_elements__*__elem_location", :finder__search_args, :finder__options ], expand_inline_fields: [ :finder ], exclude_fields: [ :finder__return_value, :finder__function_name, :finder__args__0, :finder__search_args, :finder__options, :finder__report_options, :finder__test_object, "finder__all_elements__*__found_element", "finder__all_other_elements__*__found_element" ] } } configurations.configured_reports = {} end |
Instance Attribute Details
#configurations ⇒ Object
Returns the value of attribute configurations.
13 14 15 |
# File 'lib/cornucopia/util/configuration.rb', line 13 def configurations @configurations end |
Class Method Details
.add_log_file(log_file_name, options = {}) ⇒ Object
Adds the specified log file to the list of log files to capture. If the log file is already in the list, the passed in options will be merged with the existing options. See Cornucopia::LogCapture
502 503 504 505 506 |
# File 'lib/cornucopia/util/configuration.rb', line 502 def add_log_file(log_file_name, = {}) Cornucopia::Util::Configuration.instance.configurations.user_log_files[log_file_name] ||= {} Cornucopia::Util::Configuration.instance.configurations.user_log_files[log_file_name] = Cornucopia::Util::Configuration.instance.configurations.user_log_files[log_file_name].merge end |
.analyze_find_exceptions ⇒ Object
This setting is used by the Capybara utilities.
When Capybara::Node.find throws an exception, if this is set, the system will try to use the FinderDiagnostics to output some diagnostic information about the page and the finder to try to assist in determining what happened.
596 597 598 |
# File 'lib/cornucopia/util/configuration.rb', line 596 def analyze_find_exceptions Cornucopia::Util::Configuration.instance.configurations.analyze_find_exceptions end |
.analyze_find_exceptions=(value) ⇒ Object
600 601 602 |
# File 'lib/cornucopia/util/configuration.rb', line 600 def analyze_find_exceptions=(value) Cornucopia::Util::Configuration.instance.configurations.analyze_find_exceptions = value end |
.analyze_selector_exceptions ⇒ Object
This setting is used by the Capybara utilities.
When Capybara::Node.analyze_selector throws an exception, if this is set, the system will try to use the FinderDiagnostics to output some diagnostic information about the page and the selector to try to assist in determining what happened.
609 610 611 |
# File 'lib/cornucopia/util/configuration.rb', line 609 def analyze_selector_exceptions Cornucopia::Util::Configuration.instance.configurations.analyze_selector_exceptions end |
.analyze_selector_exceptions=(value) ⇒ Object
613 614 615 |
# File 'lib/cornucopia/util/configuration.rb', line 613 def analyze_selector_exceptions=(value) Cornucopia::Util::Configuration.instance.configurations.analyze_selector_exceptions = value end |
.auto_open_report_after_generation(open_report, report_name = nil) ⇒ Object
To make it easier to know about and to see the reports, this configuration will cause a report to be automatically opened if there is anything to report when the report is closed.
The posible values for report_name are:
nil
"rspec_report"
"cucumber_report"
"spinach_report"
680 681 682 |
# File 'lib/cornucopia/util/configuration.rb', line 680 def auto_open_report_after_generation(open_report, report_name = nil) Cornucopia::Util::Configuration.instance.configurations.open_report_settings[report_name || :default] = open_report end |
.backup_logs_on_failure ⇒ Object
471 472 473 |
# File 'lib/cornucopia/util/configuration.rb', line 471 def backup_logs_on_failure Cornucopia::Util::Configuration.instance.configurations.backup_logs_on_failure end |
.backup_logs_on_failure=(value) ⇒ Object
backup_logs_on_failure causes the system to copy the log files at the end of the report cycle if there were any errors during the creation of the report system.
The system will try to grab the following log files:
* Rails.env.log
* any user specified logs
The log capture is done with a simple file copy.
Related options:
user_log_files
num_lines
add_log_file
remove_log_file
grab_logs
467 468 469 |
# File 'lib/cornucopia/util/configuration.rb', line 467 def backup_logs_on_failure=(value) Cornucopia::Util::Configuration.instance.configurations.backup_logs_on_failure = value end |
.base_folder ⇒ Object
Sets or returns the name of the folder to generate reports into.
Default: "cornucopia_report"
720 721 722 |
# File 'lib/cornucopia/util/configuration.rb', line 720 def base_folder Cornucopia::Util::Configuration.instance.configurations.base_folder end |
.base_folder=(value) ⇒ Object
724 725 726 |
# File 'lib/cornucopia/util/configuration.rb', line 724 def base_folder=(value) Cornucopia::Util::Configuration.instance.configurations.base_folder = value end |
.benchmark ⇒ Object
Turns benchmarking on or off.
Defaults to false.
758 759 760 |
# File 'lib/cornucopia/util/configuration.rb', line 758 def benchmark Cornucopia::Util::Configuration.instance.configurations.benchmark end |
.benchmark=(value) ⇒ Object
762 763 764 |
# File 'lib/cornucopia/util/configuration.rb', line 762 def benchmark=(value) Cornucopia::Util::Configuration.instance.configurations.benchmark = value end |
.context_seed ⇒ Object
388 389 390 |
# File 'lib/cornucopia/util/configuration.rb', line 388 def context_seed Cornucopia::Util::Configuration.instance.configurations.rand_context_seed end |
.context_seed=(value) ⇒ Object
rand_context_seed is the seed value used to seed the srand function at the start of a context. This is done to allow tests with random elements in them to be repeatable. If a test fails, simply set Cornucopia::Util::Configuration.rand_context_seed to the value of the failed tests context_seed value (output in the stdout and the generated report) and run the test again. This should re-run the exact same test, resulting in a repeatable test even with randomization in it.
383 384 385 386 |
# File 'lib/cornucopia/util/configuration.rb', line 383 def context_seed=(value) Cornucopia::Util::Configuration.instance.configurations.rand_context_seed = value srand(value) if value end |
.default_num_lines=(value) ⇒ Object
default_num_lines sets the default number of lines to extract from the log file
494 495 496 |
# File 'lib/cornucopia/util/configuration.rb', line 494 def default_num_lines=(value) Cornucopia::Util::Configuration.instance.configurations.default_num_lines = value end |
.default_report_configuration(report_name) ⇒ Object
returns the report configuration object for that type of report
values for report_name:
:rspec
:cucumber
:spinach
:capybara_page_diagnostics
549 550 551 |
# File 'lib/cornucopia/util/configuration.rb', line 549 def default_report_configuration(report_name) Cornucopia::Util::Configuration.instance.configurations.default_configuration[report_name].try :clone end |
.grab_logs ⇒ Object
448 449 450 |
# File 'lib/cornucopia/util/configuration.rb', line 448 def grab_logs Cornucopia::Util::Configuration.instance.configurations.grab_logs end |
.grab_logs=(value) ⇒ Object
grab_logs indicates if the system should try to automatically grab a tail of the log file if outputing a diagnostics report.
The system will try to grab the following log files:
* Rails.env.log
* any user specified logs
The log capture is done by reading from the end of the file of the log file. If the log file cannot be found, or if the system cannot open the file (no access rights, etc.) nothing will be output.
Related options:
user_log_files
num_lines
add_log_file
remove_log_file
444 445 446 |
# File 'lib/cornucopia/util/configuration.rb', line 444 def grab_logs=(value) Cornucopia::Util::Configuration.instance.configurations.grab_logs = value end |
.ignore_finder_errors_on_success ⇒ Object
This setting is used by the report builder.
If a test has finder errors but still succeeds, ignore the errors and do not report them. This is useful for tests that test the existence of an element on the page using something like: expect(my_page).not_to have_page_element
622 623 624 |
# File 'lib/cornucopia/util/configuration.rb', line 622 def ignore_finder_errors_on_success Cornucopia::Util::Configuration.instance.configurations.ignore_finder_errors_on_success end |
.ignore_finder_errors_on_success=(value) ⇒ Object
626 627 628 |
# File 'lib/cornucopia/util/configuration.rb', line 626 def ignore_finder_errors_on_success=(value) Cornucopia::Util::Configuration.instance.configurations.ignore_finder_errors_on_success = value end |
.ignore_has_selector_errors ⇒ Object
This setting is used by the matcher analysis.
Generally speaking has_selector? is allowed to return true or false without needing to be to analyzed. So, the system ignores has_selector? failures and doesn't output an analysis.
This will perform an analysis for each has_selector? failure.
636 637 638 |
# File 'lib/cornucopia/util/configuration.rb', line 636 def ignore_has_selector_errors Cornucopia::Util::Configuration.instance.configurations.ignore_has_selector_errors end |
.ignore_has_selector_errors=(value) ⇒ Object
640 641 642 |
# File 'lib/cornucopia/util/configuration.rb', line 640 def ignore_has_selector_errors=(value) Cornucopia::Util::Configuration.instance.configurations.ignore_has_selector_errors = value end |
.num_lines(log_file_name = nil) ⇒ Object
num_lines returns the number of lines that will be grabbed for a file. If no file name is supplied, or the name does not match a user file, the default log length will returned.
488 489 490 491 |
# File 'lib/cornucopia/util/configuration.rb', line 488 def num_lines(log_file_name=nil) Cornucopia::Util::Configuration.instance.configurations.user_log_files[log_file_name].try(:[], :num_lines) || Cornucopia::Util::Configuration.instance.configurations.default_num_lines end |
.open_report_after_generation(report_name) ⇒ Object
684 685 686 687 688 |
# File 'lib/cornucopia/util/configuration.rb', line 684 def open_report_after_generation(report_name) open_report = Cornucopia::Util::Configuration.instance.configurations.open_report_settings[report_name] open_report = Cornucopia::Util::Configuration.instance.configurations.open_report_settings[:default] if open_report.nil? open_report end |
.order_seed ⇒ Object
424 425 426 |
# File 'lib/cornucopia/util/configuration.rb', line 424 def order_seed Cornucopia::Util::Configuration.instance.configurations.order_seed end |
.order_seed=(value) ⇒ Object
order_seed is the seed value used to set the order that randomly ordered tests are run in. This is provided as a convenience method. I think it is easier to set this in rails_helper than it is to set it on the command line. This also provides a uniform method to do it.
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/cornucopia/util/configuration.rb', line 410 def order_seed=(value) Cornucopia::Util::Configuration.instance.configurations.order_seed = value if value if RSpec.configuration.respond_to?(:seed) RSpec.configuration.seed = value else # :nocov: RSpec.configuration.ordering_manager.seed = value # :nocov: end end end |
.print_timeout_min ⇒ Object
Sets or returns the minimum amount of time in seconds to allow for the printing of variables. If it is available, the larger of this value and Capybara.default_wait_time will be used.
This value exists to prevent the printing of a value on a report from taking too long and holding up the system. If it takes longer than this amount of time to get the value it probably isn't diagnostically important.
Default: 10
561 562 563 |
# File 'lib/cornucopia/util/configuration.rb', line 561 def print_timeout_min Cornucopia::Util::Configuration.instance.configurations.print_timeout_min end |
.print_timeout_min=(value) ⇒ Object
565 566 567 |
# File 'lib/cornucopia/util/configuration.rb', line 565 def print_timeout_min=(value) Cornucopia::Util::Configuration.instance.configurations.print_timeout_min = value end |
.record_test_start_and_end_format ⇒ Object
This setting is used by the test system hooks.
This value specifies the text that is output into the log file at the start/end of a test. Two variables are passed into the format string to be inserted into the text:
* %{start_end} - This will be either "Start" or "End"
* %{test_name} - This will the the name of the test.
747 748 749 |
# File 'lib/cornucopia/util/configuration.rb', line 747 def record_test_start_and_end_format Cornucopia::Util::Configuration.instance.configurations.record_test_start_and_end_format end |
.record_test_start_and_end_format=(value) ⇒ Object
751 752 753 |
# File 'lib/cornucopia/util/configuration.rb', line 751 def record_test_start_and_end_format=(value) Cornucopia::Util::Configuration.instance.configurations.record_test_start_and_end_format = value end |
.record_test_start_and_end_in_log ⇒ Object
This setting is used by the test system hooks.
If true (the default) this will cause the system to output a line to the Rails log indicating when a test starts and when it ends.
732 733 734 |
# File 'lib/cornucopia/util/configuration.rb', line 732 def record_test_start_and_end_in_log Cornucopia::Util::Configuration.instance.configurations.record_test_start_and_end_in_log end |
.record_test_start_and_end_in_log=(value) ⇒ Object
736 737 738 |
# File 'lib/cornucopia/util/configuration.rb', line 736 def record_test_start_and_end_in_log=(value) Cornucopia::Util::Configuration.instance.configurations.record_test_start_and_end_in_log = value end |
.remove_log_file(log_file_name) ⇒ Object
Removes the specified log file from the list of log files to capture. NOTE: You cannot remove the default log file.
510 511 512 |
# File 'lib/cornucopia/util/configuration.rb', line 510 def remove_log_file(log_file_name) Cornucopia::Util::Configuration.instance.configurations.user_log_files.delete log_file_name end |
.report_configuration(report_name) ⇒ Object
returns the report configuration object for that type of report
values for report_name:
:rspec
:cucumber
:spinach
:capybara_page_diagnostics
521 522 523 524 |
# File 'lib/cornucopia/util/configuration.rb', line 521 def report_configuration(report_name) Cornucopia::Util::Configuration.instance.configurations.configured_reports[report_name] ||= Cornucopia::Util::ConfiguredReport.new(Cornucopia::Util::Configuration.instance.configurations.default_configuration[report_name]) end |
.retry_match_with_found ⇒ Object
Sometimes, the analysis process found the element when it wasn't found other ways. This will cause the match accessor to try again with the found element.
The default is true because I have been getting a fair number of false negatives.
663 664 665 |
# File 'lib/cornucopia/util/configuration.rb', line 663 def retry_match_with_found Cornucopia::Util::Configuration.instance.configurations.retry_match_with_found end |
.retry_match_with_found=(value) ⇒ Object
667 668 669 |
# File 'lib/cornucopia/util/configuration.rb', line 667 def retry_match_with_found=(value) Cornucopia::Util::Configuration.instance.configurations.retry_match_with_found = value end |
.retry_with_found ⇒ Object
Sometimes, the analysis process found the element when it wasn't found other ways. This will cause the finder to try again with the found element.
The default is false because I haven't seen this be useful in a while.
WARNING: Using this is unsafe. If you use it, you could get false positive results in your test.
651 652 653 |
# File 'lib/cornucopia/util/configuration.rb', line 651 def retry_with_found Cornucopia::Util::Configuration.instance.configurations.retry_with_found end |
.retry_with_found=(value) ⇒ Object
655 656 657 |
# File 'lib/cornucopia/util/configuration.rb', line 655 def retry_with_found=(value) Cornucopia::Util::Configuration.instance.configurations.retry_with_found = value end |
.seed ⇒ Object
373 374 375 |
# File 'lib/cornucopia/util/configuration.rb', line 373 def seed Cornucopia::Util::Configuration.instance.configurations.rand_seed end |
.seed=(value) ⇒ Object
rand_seed is the seed value used to seed the srand function at the start of a test suite. This is done to allow tests with random elements in them to be repeatable. If a test fails, simply set Cornucopia::Util::Configuration.rand_seed to the value of the failed tests seed value (output in the stdout and the generated report) and run the test again. This should re-run the exact same test, resulting in a repeatable test even with randomization in it.
368 369 370 371 |
# File 'lib/cornucopia/util/configuration.rb', line 368 def seed=(value) Cornucopia::Util::Configuration.instance.configurations.rand_seed = value srand(value) if value end |
.selenium_cache_retry_count ⇒ Object
The Selenium driver can throw a StaleElementReferenceError exception sometimes. I often see it with animated items like dialog boxes and the like. When the system is looping trying to find the element or stop seeing it.
Because the element likely just disappeared between when it was found and when it was returned, trying again will often make the problem go away.
The default for this setting is 5 which will retry the find function if this error occurs.
NOTE: This should already be the default action (basically) for the Selenium driver, yet from a purely practical standpoint, this seems to be a problem that I've run into a lot. I am doing it this way to see if I can reduce the the occurrence of it.
583 584 585 |
# File 'lib/cornucopia/util/configuration.rb', line 583 def selenium_cache_retry_count Cornucopia::Util::Configuration.instance.configurations.selenium_cache_retry_count end |
.selenium_cache_retry_count=(value) ⇒ Object
587 588 589 |
# File 'lib/cornucopia/util/configuration.rb', line 587 def selenium_cache_retry_count=(value) Cornucopia::Util::Configuration.instance.configurations.selenium_cache_retry_count = value end |
.set_report_configuration(report_name, configuration) ⇒ Object
sets the report configuration object for that type of report from a configuration has that is passed in
values for report_name:
:rspec
:cucumber
:spinach
:capybara_page_diagnostics
533 534 535 536 537 538 539 540 |
# File 'lib/cornucopia/util/configuration.rb', line 533 def set_report_configuration(report_name, configuration) if configuration.is_a?(Cornucopia::Util::ConfiguredReport) Cornucopia::Util::Configuration.instance.configurations.configured_reports[report_name] = configuration else Cornucopia::Util::Configuration.instance.configurations.configured_reports[report_name] = Cornucopia::Util::ConfiguredReport.new(configuration) end end |
.suite_seed ⇒ Object
403 404 405 |
# File 'lib/cornucopia/util/configuration.rb', line 403 def suite_seed Cornucopia::Util::Configuration.instance.configurations.rand_suite_seed end |
.suite_seed=(value) ⇒ Object
rand_suite_seed is the seed value used to seed the srand function at the start of a context. This is done to allow tests with random elements in them to be repeatable. If a test fails, simply set Cornucopia::Util::Configuration.rand_suite_seed to the value of the failed tests suite_seed value (output in the stdout and the generated report) and run the test again. This should re-run the exact same test, resulting in a repeatable test even with randomization in it.
398 399 400 401 |
# File 'lib/cornucopia/util/configuration.rb', line 398 def suite_seed=(value) Cornucopia::Util::Configuration.instance.configurations.rand_suite_seed = value srand(value) if value end |
.user_log_files ⇒ Object
user_log_files returns a hash of all of the log files which the user has specified are to be grabbed.
The keys are the relative paths of the log files to be grabbed, and the values are the options specified for the files. The values may be an empty hash.
481 482 483 |
# File 'lib/cornucopia/util/configuration.rb', line 481 def user_log_files Cornucopia::Util::Configuration.instance.configurations.user_log_files.clone end |